@@ -1253,7 +1253,7 @@ class NiftiWrapper(object):
 
     def __init__(self, nii_img, make_empty=False):
         self.nii_img = nii_img
-        hdr = nii_img.get_header()
+        hdr = nii_img.header
         self.meta_ext = None
         for extension in hdr.extensions:
             if extension.get_code() == dcm_meta_ecode:
@@ -1292,19 +1292,19 @@ class NiftiWrapper(object):
         if classification == ('global', 'const'):
             return True
 
-        img_shape = self.nii_img.get_shape()
+        img_shape = self.nii_img.shape
         meta_shape = self.meta_ext.shape
         if classification == ('vector', 'samples'):
             return meta_shape[4:] == img_shape[4:]
         if classification == ('time', 'samples'):
             return meta_shape[3:] == img_shape[3:]
 
-        hdr = self.nii_img.get_header()
+        hdr = self.nii_img.header
         if self.meta_ext.n_slices != hdr.get_n_slices():
             return False
 
         slice_dim = hdr.get_dim_info()[2]
-        slice_dir = self.nii_img.get_affine()[slice_dim, :3]
+        slice_dir = self.nii_img.affine[slice_dim, :3]
         slices_aligned = np.allclose(slice_dir,
                                      self.meta_ext.slice_normal,
                                      atol=1e-6)
@@ -1357,7 +1357,7 @@ class NiftiWrapper(object):
         #If an index is provided check the varying values
         if not index is None:
             #Test if the index is valid
-            shape = self.nii_img.get_shape()
+            shape = self.nii_img.shape
             if len(index) != len(shape):
                 raise IndexError('Incorrect number of indices.')
             for dim, ind_val in enumerate(index):
@@ -1371,7 +1371,7 @@ class NiftiWrapper(object):
                 return values[index[4]]
 
             #Finally, if aligned, try per-slice values
-            slice_dim = self.nii_img.get_header().get_dim_info()[2]
+            slice_dim = self.nii_img.header.get_dim_info()[2]
             n_slices = shape[slice_dim]
             if classes == ('global', 'slices'):
                 val_idx = index[slice_dim]
@@ -1392,7 +1392,7 @@ class NiftiWrapper(object):
     def remove_extension(self):
         '''Remove the DcmMetaExtension from the header of nii_img. The
         attribute `meta_ext` will still point to the extension.'''
-        hdr = self.nii_img.get_header()
+        hdr = self.nii_img.header
         target_idx = None
         for idx, ext in enumerate(hdr.extensions):
             if id(ext) == id(self.meta_ext):
@@ -1414,7 +1414,7 @@ class NiftiWrapper(object):
 
         '''
         self.remove_extension()
-        self.nii_img.get_header().extensions.append(dcmmeta_ext)
+        self.nii_img.header.extensions.append(dcmmeta_ext)
         self.meta_ext = dcmmeta_ext
 
     def split(self, dim=None):
@@ -1434,9 +1434,9 @@ class NiftiWrapper(object):
             along `dim`.
 
         '''
-        shape = self.nii_img.get_shape()
+        shape = self.nii_img.shape
         data = self.nii_img.get_data()
-        header = self.nii_img.get_header()
+        header = self.nii_img.header
         slice_dim = header.get_dim_info()[2]
 
         #If dim is None, choose the vector/time/slice dim in that order
@@ -1541,7 +1541,7 @@ class NiftiWrapper(object):
 
         #Create the nifti image and set header data
         nii_img = nb.nifti1.Nifti1Image(data, affine)
-        hdr = nii_img.get_header()
+        hdr = nii_img.header
         hdr.set_xyzt_units('mm', 'sec')
         dim_info = {'freq' : None,
                     'phase' : None,
@@ -1606,9 +1606,9 @@ class NiftiWrapper(object):
         n_inputs = len(seq)
         first_input = seq[0]
         first_nii = first_input.nii_img
-        first_hdr = first_nii.get_header()
+        first_hdr = first_nii.header
         shape = first_nii.shape
-        affine = first_nii.get_affine().copy()
+        affine = first_nii.affine.copy()
 
         #If dim is None, choose a sane default
         if dim is None:
@@ -1683,8 +1683,8 @@ class NiftiWrapper(object):
 
             input_wrp = seq[input_idx]
             input_nii = input_wrp.nii_img
-            input_aff = input_nii.get_affine()
-            input_hdr = input_nii.get_header()
+            input_aff = input_nii.affine
+            input_hdr = input_nii.header
 
             #Check that the affines match appropriately
             for axis_idx, axis_vec in enumerate(axes):
@@ -1768,12 +1768,12 @@ class NiftiWrapper(object):
         #If we joined along a spatial dim, rescale the appropriate axis
         scaled_dim_dir = None
         if dim < 3:
-            scaled_dim_dir = seq[1].nii_img.get_affine()[:3, 3] - trans
+            scaled_dim_dir = seq[1].nii_img.affine[:3, 3] - trans
             affine[:3, dim] = scaled_dim_dir
 
         #Create the resulting Nifti and wrapper
         result_nii = nb.Nifti1Image(result_data, affine)
-        result_hdr = result_nii.get_header()
+        result_hdr = result_nii.header
 
         #Update the header with any info that is consistent across inputs
         if hdr_info['qform'] is not None and hdr_info['qform_code'] is not None:
